Cheshire3 Documentation

|  | ## Cheshire3 Documentation

Introduction

Welcome to the Cheshire3 Information Framework. Below is everything that you should need to install, configure, understand and develop solutions using Cheshire3. If not, let us know and we'll try to add it.

Capabilities What Cheshire3 can do:

- Create a database of your documents, and put a search engine on top.
- Index the full text of those documents, and allow you to set up your own indexes of specific fields within structured documents.
- Set up these indexes to extract and normalize the data exactly the way you need (e.g. make an index of people's names as keywords, strip off possissive apostrophes, treat all names as lowercase)
- Search the indexes you've set up to quickly find the document you want. When searching indexes the search terms are treated the same way as the data, so a user doesn't need to know what normalization you've applied, they'll just get the correct results!
- Advanced boolean search logic ('AND', 'OR', 'NOT') as well as proximity, phrase and range searching (e.g. for date/time periods).
- Return shared 'facets' of your search results to indicate ways in which a search could be refined.
- Scan through all terms in an index, just like reading the index in a book.
- Add international standard webservice APIs to your database
- Use an existing Relation Database Management Systems as a source of documents.
- [More Coming]

Installation

- How to Install Cheshire3
- Troubleshooting

Building Databases

- Configuring and Building a Database

Interface Development

- Search and Display example
- Apache web interface example (long)

Development Details

- Configuration of Cheshire3
- Cheshire3 Object Model